@@ -1,20 +1,9 @@
 #!/usr/bin/env perl
-
-use strict;
-use warnings;
-use Getopt::Long;
-use Pod::Usage;
 use FindBin;
-use lib "$FindBin::Bin/../lib";
-use Catalyst::Test 'Gitalist';
+BEGIN { do "$FindBin::Bin/env" or die $@ }
 
-my $help = 0;
-
-GetOptions( 'help|?' => \$help );
-
-pod2usage(1) if ( $help || !$ARGV[0] );
-
-print request($ARGV[0])->content . "\n";
+use Catalyst::ScriptRunner;
+Catalyst::ScriptRunner->run('Gitalist','Test');
 
 1;
 
